==> haskell-hasql-pool-0.5.1-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-pool
version:              0.5.1
visibility:           public
id:                   hasql-pool-0.5.1-E3NK7pVK5UYLKQU8olroK7
key:                  hasql-pool-0.5.1-E3NK7pVK5UYLKQU8olroK7
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  d3d7e49a89e7ae5709b7c1cdc9717ccf
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-8.8.1/site-local/hasql-pool-0.5.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/hasql-pool-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/hasql-pool-0.5.1
hs-libraries:         HShasql-pool-0.5.1-E3NK7pVK5UYLKQU8olroK7
depends:
    base-prelude-1.3-GkjcM0d5Bef5VOhNpPY6Ft
    hasql-1.4.0.1-FrePtqVMG5ADHXGsxmaIph
    resource-pool-0.2.3.2-3tEXfLLoOjE5h8Qr8YDuzQ time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.5.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-pool
version:              0.5.1
visibility:           public
id:                   hasql-pool-0.5.1-EN807WxTDl4FzKNTc0H6kj
key:                  hasql-pool-0.5.1-EN807WxTDl4FzKNTc0H6kj
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  723cf31de313c6479f4d9d435d1434e2
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-8.8.2/site-local/hasql-pool-0.5.1
library-dirs:         /usr/lib/ghc-8.8.2/site-local/hasql-pool-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/hasql-pool-0.5.1
hs-libraries:         HShasql-pool-0.5.1-EN807WxTDl4FzKNTc0H6kj
depends:
    base-prelude-1.3-GkjcM0d5Bef5VOhNpPY6Ft
    hasql-1.4.0.1-DMANEYr1EdRH5nh7HoJR9S
    resource-pool-0.2.3.2-3PoWN2oiuxIFBwTwHOTQaf time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
